@@ -4,5 +4,6 @@ This package provides tools to iterate over dataframe with windows.
 """
 
 from mlcf.windowing.iterator.forecast_iterator import WindowForecastIterator  # noqa
-from mlcf.windowing.iterator.iterator import WindowIterator  # noqa
-from mlcf.windowing.iterator.tseries import WTSeries  # noqa
\ No newline at end of file
+from mlcf.windowing.iterator.iterator import WindowIterator, SUFFIX_FILE  # noqa
+from mlcf.windowing.iterator.tseries import WTSeries  # noqa
+from mlcf.windowing.iterator.tseries_lite import WTSeriesLite  # noqa
\ No newline at end of file
